# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcloudauth.endpoint import endpoint_data

class DescribeVerifyTokenRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'DescribeVerifyToken','cloudauth')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_FaceRetainedImageUrl(self):
		return self.get_query_params().get('FaceRetainedImageUrl')

	def set_FaceRetainedImageUrl(self,FaceRetainedImageUrl):
		self.add_query_param('FaceRetainedImageUrl',FaceRetainedImageUrl)

	def get_UserId(self):
		return self.get_query_params().get('UserId')

	def set_UserId(self,UserId):
		self.add_query_param('UserId',UserId)

	def get_CallbackSeed(self):
		return self.get_query_params().get('CallbackSeed')

	def set_CallbackSeed(self,CallbackSeed):
		self.add_query_param('CallbackSeed',CallbackSeed)

	def get_UserIp(self):
		return self.get_query_params().get('UserIp')

	def set_UserIp(self,UserIp):
		self.add_query_param('UserIp',UserIp)

	def get_IdCardBackImageUrl(self):
		return self.get_query_params().get('IdCardBackImageUrl')

	def set_IdCardBackImageUrl(self,IdCardBackImageUrl):
		self.add_query_param('IdCardBackImageUrl',IdCardBackImageUrl)

	def get_IdCardNumber(self):
		return self.get_query_params().get('IdCardNumber')

	def set_IdCardNumber(self,IdCardNumber):
		self.add_query_param('IdCardNumber',IdCardNumber)

	def get_IdCardFrontImageUrl(self):
		return self.get_query_params().get('IdCardFrontImageUrl')

	def set_IdCardFrontImageUrl(self,IdCardFrontImageUrl):
		self.add_query_param('IdCardFrontImageUrl',IdCardFrontImageUrl)

	def get_BizType(self):
		return self.get_query_params().get('BizType')

	def set_BizType(self,BizType):
		self.add_query_param('BizType',BizType)

	def get_PassedRedirectUrl(self):
		return self.get_query_params().get('PassedRedirectUrl')

	def set_PassedRedirectUrl(self,PassedRedirectUrl):
		self.add_query_param('PassedRedirectUrl',PassedRedirectUrl)

	def get_UserRegistTime(self):
		return self.get_query_params().get('UserRegistTime')

	def set_UserRegistTime(self,UserRegistTime):
		self.add_query_param('UserRegistTime',UserRegistTime)

	def get_BizId(self):
		return self.get_query_params().get('BizId')

	def set_BizId(self,BizId):
		self.add_query_param('BizId',BizId)

	def get_Name(self):
		return self.get_query_params().get('Name')

	def set_Name(self,Name):
		self.add_query_param('Name',Name)

	def get_UserPhoneNumber(self):
		return self.get_query_params().get('UserPhoneNumber')

	def set_UserPhoneNumber(self,UserPhoneNumber):
		self.add_query_param('UserPhoneNumber',UserPhoneNumber)

	def get_CallbackUrl(self):
		return self.get_query_params().get('CallbackUrl')

	def set_CallbackUrl(self,CallbackUrl):
		self.add_query_param('CallbackUrl',CallbackUrl)

	def get_FailedRedirectUrl(self):
		return self.get_query_params().get('FailedRedirectUrl')

	def set_FailedRedirectUrl(self,FailedRedirectUrl):
		self.add_query_param('FailedRedirectUrl',FailedRedirectUrl)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcloudauth.endpoint import endpoint_data

class InitDeviceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'InitDevice','cloudauth')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_Channel(self):
		return self.get_query_params().get('Channel')

	def set_Channel(self,Channel):
		self.add_query_param('Channel',Channel)

	def get_BizData(self):
		return self.get_query_params().get('BizData')

	def set_BizData(self,BizData):
		self.add_query_param('BizData',BizData)

	def get_Merchant(self):
		return self.get_query_params().get('Merchant')

	def set_Merchant(self,Merchant):
		self.add_query_param('Merchant',Merchant)

	def get_AppVersion(self):
		return self.get_query_params().get('AppVersion')

	def set_AppVersion(self,AppVersion):
		self.add_query_param('AppVersion',AppVersion)

	def get_DeviceToken(self):
		return self.get_query_params().get('DeviceToken')

	def set_DeviceToken(self,DeviceToken):
		self.add_query_param('DeviceToken',DeviceToken)

	def get_CertifyId(self):
		return self.get_query_params().get('CertifyId')

	def set_CertifyId(self,CertifyId):
		self.add_query_param('CertifyId',CertifyId)

	def get_OuterOrderNo(self):
		return self.get_query_params().get('OuterOrderNo')

	def set_OuterOrderNo(self,OuterOrderNo):
		self.add_query_param('OuterOrderNo',OuterOrderNo)

	def get_ProduceNode(self):
		return self.get_query_params().get('ProduceNode')

	def set_ProduceNode(self,ProduceNode):
		self.add_query_param('ProduceNode',ProduceNode)

	def get_ProductName(self):
		return self.get_query_params().get('ProductName')

	def set_ProductName(self,ProductName):
		self.add_query_param('ProductName',ProductName)

	def get_CertifyPrincipal(self):
		return self.get_query_params().get('CertifyPrincipal')

	def set_CertifyPrincipal(self,CertifyPrincipal):
		self.add_query_param('CertifyPrincipal',CertifyPrincipal)

	def get_MetaInfo(self):
		return self.get_query_params().get('MetaInfo')

	def set_MetaInfo(self,MetaInfo):
		self.add_query_param('MetaInfo',MetaInfo)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcloudauth.endpoint import endpoint_data

class CompareFaceVerifyRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'CompareFaceVerify','cloudauth')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_TargetFaceContrastPictureUrl(self):
		return self.get_body_params().get('TargetFaceContrastPictureUrl')

	def set_TargetFaceContrastPictureUrl(self,TargetFaceContrastPictureUrl):
		self.add_body_params('TargetFaceContrastPictureUrl', TargetFaceContrastPictureUrl)

	def get_ProductCode(self):
		return self.get_body_params().get('ProductCode')

	def set_ProductCode(self,ProductCode):
		self.add_body_params('ProductCode', ProductCode)

	def get_TargetCertifyId(self):
		return self.get_body_params().get('TargetCertifyId')

	def set_TargetCertifyId(self,TargetCertifyId):
		self.add_body_params('TargetCertifyId', TargetCertifyId)

	def get_SourceOssObjectName(self):
		return self.get_body_params().get('SourceOssObjectName')

	def set_SourceOssObjectName(self,SourceOssObjectName):
		self.add_body_params('SourceOssObjectName', SourceOssObjectName)

	def get_TargetFaceContrastPicture(self):
		return self.get_body_params().get('TargetFaceContrastPicture')

	def set_TargetFaceContrastPicture(self,TargetFaceContrastPicture):
		self.add_body_params('TargetFaceContrastPicture', TargetFaceContrastPicture)

	def get_TargetOssBucketName(self):
		return self.get_body_params().get('TargetOssBucketName')

	def set_TargetOssBucketName(self,TargetOssBucketName):
		self.add_body_params('TargetOssBucketName', TargetOssBucketName)

	def get_SourceOssBucketName(self):
		return self.get_body_params().get('SourceOssBucketName')

	def set_SourceOssBucketName(self,SourceOssBucketName):
		self.add_body_params('SourceOssBucketName', SourceOssBucketName)

	def get_OuterOrderNo(self):
		return self.get_body_params().get('OuterOrderNo')

	def set_OuterOrderNo(self,OuterOrderNo):
		self.add_body_params('OuterOrderNo', OuterOrderNo)

	def get_TargetOssObjectName(self):
		return self.get_body_params().get('TargetOssObjectName')

	def set_TargetOssObjectName(self,TargetOssObjectName):
		self.add_body_params('TargetOssObjectName', TargetOssObjectName)

	def get_SourceFaceContrastPicture(self):
		return self.get_body_params().get('SourceFaceContrastPicture')

	def set_SourceFaceContrastPicture(self,SourceFaceContrastPicture):
		self.add_body_params('SourceFaceContrastPicture', SourceFaceContrastPicture)

	def get_SceneId(self):
		return self.get_body_params().get('SceneId')

	def set_SceneId(self,SceneId):
		self.add_body_params('SceneId', SceneId)

	def get_SourceFaceContrastPictureUrl(self):
		return self.get_body_params().get('SourceFaceContrastPictureUrl')

	def set_SourceFaceContrastPictureUrl(self,SourceFaceContrastPictureUrl):
		self.add_body_params('SourceFaceContrastPictureUrl', SourceFaceContrastPictureUrl)

	def get_SourceCertifyId(self):
		return self.get_body_params().get('SourceCertifyId')

	def set_SourceCertifyId(self,SourceCertifyId):
		self.add_body_params('SourceCertifyId', SourceCertifyId)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcloudauth.endpoint import endpoint_data

class ContrastFaceVerifyRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'ContrastFaceVerify','cloudauth')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ProductCode(self):
		return self.get_body_params().get('ProductCode')

	def set_ProductCode(self,ProductCode):
		self.add_body_params('ProductCode', ProductCode)

	def get_OssObjectName(self):
		return self.get_body_params().get('OssObjectName')

	def set_OssObjectName(self,OssObjectName):
		self.add_body_params('OssObjectName', OssObjectName)

	def get_FaceContrastPicture(self):
		return self.get_body_params().get('FaceContrastPicture')

	def set_FaceContrastPicture(self,FaceContrastPicture):
		self.add_body_params('FaceContrastPicture', FaceContrastPicture)

	def get_CertName(self):
		return self.get_body_params().get('CertName')

	def set_CertName(self,CertName):
		self.add_body_params('CertName', CertName)

	def get_Ip(self):
		return self.get_body_params().get('Ip')

	def set_Ip(self,Ip):
		self.add_body_params('Ip', Ip)

	def get_Mobile(self):
		return self.get_body_params().get('Mobile')

	def set_Mobile(self,Mobile):
		self.add_body_params('Mobile', Mobile)

	def get_DeviceToken(self):
		return self.get_body_params().get('DeviceToken')

	def set_DeviceToken(self,DeviceToken):
		self.add_body_params('DeviceToken', DeviceToken)

	def get_UserId(self):
		return self.get_body_params().get('UserId')

	def set_UserId(self,UserId):
		self.add_body_params('UserId', UserId)

	def get_CertifyId(self):
		return self.get_body_params().get('CertifyId')

	def set_CertifyId(self,CertifyId):
		self.add_body_params('CertifyId', CertifyId)

	def get_CertNo(self):
		return self.get_body_params().get('CertNo')

	def set_CertNo(self,CertNo):
		self.add_body_params('CertNo', CertNo)

	def get_OuterOrderNo(self):
		return self.get_body_params().get('OuterOrderNo')

	def set_OuterOrderNo(self,OuterOrderNo):
		self.add_body_params('OuterOrderNo', OuterOrderNo)

	def get_CertType(self):
		return self.get_body_params().get('CertType')

	def set_CertType(self,CertType):
		self.add_body_params('CertType', CertType)

	def get_FaceContrastPictureUrl(self):
		return self.get_body_params().get('FaceContrastPictureUrl')

	def set_FaceContrastPictureUrl(self,FaceContrastPictureUrl):
		self.add_body_params('FaceContrastPictureUrl', FaceContrastPictureUrl)

	def get_SceneId(self):
		return self.get_body_params().get('SceneId')

	def set_SceneId(self,SceneId):
		self.add_body_params('SceneId', SceneId)

	def get_OssBucketName(self):
		return self.get_body_params().get('OssBucketName')

	def set_OssBucketName(self,OssBucketName):
		self.add_body_params('OssBucketName', OssBucketName)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcloudauth.endpoint import endpoint_data

class DetectFaceAttributesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'DetectFaceAttributes','cloudauth')
		self.set_protocol_type('https')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_MaxNumPhotosPerCategory(self):
		return self.get_body_params().get('MaxNumPhotosPerCategory')

	def set_MaxNumPhotosPerCategory(self,MaxNumPhotosPerCategory):
		self.add_body_params('MaxNumPhotosPerCategory', MaxNumPhotosPerCategory)

	def get_MaxFaceNum(self):
		return self.get_body_params().get('MaxFaceNum')

	def set_MaxFaceNum(self,MaxFaceNum):
		self.add_body_params('MaxFaceNum', MaxFaceNum)

	def get_ResourceOwnerId(self):
		return self.get_query_params().get('ResourceOwnerId')

	def set_ResourceOwnerId(self,ResourceOwnerId):
		self.add_query_param('ResourceOwnerId',ResourceOwnerId)

	def get_RetAttributes(self):
		return self.get_body_params().get('RetAttributes')

	def set_RetAttributes(self,RetAttributes):
		self.add_body_params('RetAttributes', RetAttributes)

	def get_ClientTag(self):
		return self.get_body_params().get('ClientTag')

	def set_ClientTag(self,ClientTag):
		self.add_body_params('ClientTag', ClientTag)

	def get_SourceIp(self):
		return self.get_query_params().get('SourceIp')

	def set_SourceIp(self,SourceIp):
		self.add_query_param('SourceIp',SourceIp)

	def get_MaterialValue(self):
		return self.get_body_params().get('MaterialValue')

	def set_MaterialValue(self,MaterialValue):
		self.add_body_params('MaterialValue', MaterialValue)

	def get_DontSaveDB(self):
		return self.get_body_params().get('DontSaveDB')

	def set_DontSaveDB(self,DontSaveDB):
		self.add_body_params('DontSaveDB', DontSaveDB)